@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 96	David Albert Bagley, bagleyd@hertz.njit.edu
+#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
 #
 #                   All Rights Reserved
 #
@@ -34,7 +34,7 @@
 #ifdef VMS
 #include <unixlib.h>
 #else
-#ifndef apollo
+#if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #endif
@@ -107,12 +107,12 @@ static void XFillSector(Display * display, Drawable drawable, GC gc, int xo, int
 static void XDrawSector(Display * display, Drawable drawable, GC gc, int xo, int yo, int width1, int height1, int width2, int height2, int angle1, int angle2);
 
 #ifdef DEBUG
-static void PrintMball(MballWidget w)
-
+static void 
+PrintMball(MballWidget w)
 #endif
 
-static char defaultTranslationsMball[] =
-"<KeyPress>q: Quit()\n\
+	static char defaultTranslationsMball[] =
+	"<KeyPress>q: Quit()\n\
    Ctrl<KeyPress>C: Quit()\n\
    <KeyPress>KP_Divide: MoveCcw()\n\
    <KeyPress>Home: MoveTl()\n\
@@ -162,122 +162,124 @@ static char defaultTranslationsMball[] =
    <KeyPress>6: Wedge6()\n\
    <KeyPress>8: Wedge8()";
 
-static XtActionsRec actionsListMball[] =
-{
-	{"Quit", (XtActionProc) QuitMball},
-	{"MoveCcw", (XtActionProc) MoveMballCcw},
-	{"MoveTl", (XtActionProc) MoveMballTl},
-	{"MoveTop", (XtActionProc) MoveMballTop},
-	{"MoveTr", (XtActionProc) MoveMballTr},
-	{"MoveLeft", (XtActionProc) MoveMballLeft},
-	{"MoveCw", (XtActionProc) MoveMballCw},
-	{"MoveRight", (XtActionProc) MoveMballRight},
-	{"MoveBl", (XtActionProc) MoveMballBl},
-	{"MoveBottom", (XtActionProc) MoveMballBottom},
-	{"MoveBr", (XtActionProc) MoveMballBr},
-	{"Select", (XtActionProc) SelectMball},
-	{"Release", (XtActionProc) ReleaseMball},
-	{"Practice", (XtActionProc) PracticeMball},
-	{"PracticeMaybe", (XtActionProc) PracticeMballMaybe},
-	{"Randomize", (XtActionProc) RandomizeMball},
-	{"RandomizeMaybe", (XtActionProc) RandomizeMballMaybe},
-	{"Get", (XtActionProc) GetMball},
-	{"Write", (XtActionProc) WriteMball},
-	{"Undo", (XtActionProc) UndoMball},
-	{"Solve", (XtActionProc) SolveMball},
-	{"Increment", (XtActionProc) IncrementMball},
-	{"Decrement", (XtActionProc) DecrementMball},
-	{"Orientize", (XtActionProc) OrientizeMball},
-	{"Wedge2", (XtActionProc) Wedge2ModeMball},
-	{"Wedge4", (XtActionProc) Wedge4ModeMball},
-	{"Wedge6", (XtActionProc) Wedge6ModeMball},
-	{"Wedge8", (XtActionProc) Wedge8ModeMball}
+	static XtActionsRec actionsListMball[] =
+	{
+		{"Quit", (XtActionProc) QuitMball},
+		{"MoveCcw", (XtActionProc) MoveMballCcw},
+		{"MoveTl", (XtActionProc) MoveMballTl},
+		{"MoveTop", (XtActionProc) MoveMballTop},
+		{"MoveTr", (XtActionProc) MoveMballTr},
+		{"MoveLeft", (XtActionProc) MoveMballLeft},
+		{"MoveCw", (XtActionProc) MoveMballCw},
+		{"MoveRight", (XtActionProc) MoveMballRight},
+		{"MoveBl", (XtActionProc) MoveMballBl},
+		{"MoveBottom", (XtActionProc) MoveMballBottom},
+		{"MoveBr", (XtActionProc) MoveMballBr},
+		{"Select", (XtActionProc) SelectMball},
+		{"Release", (XtActionProc) ReleaseMball},
+		{"Practice", (XtActionProc) PracticeMball},
+		{"PracticeMaybe", (XtActionProc) PracticeMballMaybe},
+		{"Randomize", (XtActionProc) RandomizeMball},
+		{"RandomizeMaybe", (XtActionProc) RandomizeMballMaybe},
+		{"Get", (XtActionProc) GetMball},
+		{"Write", (XtActionProc) WriteMball},
+		{"Undo", (XtActionProc) UndoMball},
+		{"Solve", (XtActionProc) SolveMball},
+		{"Increment", (XtActionProc) IncrementMball},
+		{"Decrement", (XtActionProc) DecrementMball},
+		{"Orientize", (XtActionProc) OrientizeMball},
+		{"Wedge2", (XtActionProc) Wedge2ModeMball},
+		{"Wedge4", (XtActionProc) Wedge4ModeMball},
+		{"Wedge6", (XtActionProc) Wedge6ModeMball},
+		{"Wedge8", (XtActionProc) Wedge8ModeMball}
 };
 
-static XtResource resourcesMball[] =
-{
-	{XtNwedgeColor0, XtCLabel, XtRString, sizeof (String),
-	 XtOffset(MballWidget, mball.wedgeName[0]), XtRString, "Yellow"},
-	{XtNwedgeColor1, XtCLabel, XtRString, sizeof (String),
-	 XtOffset(MballWidget, mball.wedgeName[1]), XtRString, "Blue"},
-	{XtNwedgeColor2, XtCLabel, XtRString, sizeof (String),
-	 XtOffset(MballWidget, mball.wedgeName[2]), XtRString, "Red"},
-	{XtNwedgeColor3, XtCLabel, XtRString, sizeof (String),
-	 XtOffset(MballWidget, mball.wedgeName[3]), XtRString, "Magenta"},
-	{XtNwedgeColor4, XtCLabel, XtRString, sizeof (String),
-	 XtOffset(MballWidget, mball.wedgeName[4]), XtRString, "Green"},
-	{XtNwedgeColor5, XtCLabel, XtRString, sizeof (String),
-	 XtOffset(MballWidget, mball.wedgeName[5]), XtRString, "Orange"},
-	{XtNwedgeColor6, XtCLabel, XtRString, sizeof (String),
-	 XtOffset(MballWidget, mball.wedgeName[6]), XtRString, "Cyan"},
-	{XtNwedgeColor7, XtCLabel, XtRString, sizeof (String),
-	 XtOffset(MballWidget, mball.wedgeName[7]), XtRString, "DarkGreen"},
-	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
+	static XtResource resourcesMball[] =
+	{
+		{XtNuserName, XtCUserName, XtRString, sizeof (String),
+		 XtOffset(MballWidget, mball.username), XtRString, "nobody"},
+		{XtNwedgeColor0, XtCLabel, XtRString, sizeof (String),
+	     XtOffset(MballWidget, mball.wedgeName[0]), XtRString, "Yellow"},
+		{XtNwedgeColor1, XtCLabel, XtRString, sizeof (String),
+	       XtOffset(MballWidget, mball.wedgeName[1]), XtRString, "Blue"},
+		{XtNwedgeColor2, XtCLabel, XtRString, sizeof (String),
+		 XtOffset(MballWidget, mball.wedgeName[2]), XtRString, "Red"},
+		{XtNwedgeColor3, XtCLabel, XtRString, sizeof (String),
+	    XtOffset(MballWidget, mball.wedgeName[3]), XtRString, "Magenta"},
+		{XtNwedgeColor4, XtCLabel, XtRString, sizeof (String),
+	      XtOffset(MballWidget, mball.wedgeName[4]), XtRString, "Green"},
+		{XtNwedgeColor5, XtCLabel, XtRString, sizeof (String),
+	     XtOffset(MballWidget, mball.wedgeName[5]), XtRString, "Orange"},
+		{XtNwedgeColor6, XtCLabel, XtRString, sizeof (String),
+	       XtOffset(MballWidget, mball.wedgeName[6]), XtRString, "Cyan"},
+		{XtNwedgeColor7, XtCLabel, XtRString, sizeof (String),
+	  XtOffset(MballWidget, mball.wedgeName[7]), XtRString, "DarkGreen"},
+		{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
     XtOffset(MballWidget, mball.foreground), XtRString, XtDefaultForeground},
-	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
+		{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
    XtOffset(MballWidget, mball.borderColor), XtRString, XtDefaultForeground},
-	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
-	 XtOffset(MballWidget, core.width), XtRString, "200"},
-	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
-	 XtOffset(MballWidget, core.height), XtRString, "400"},
-	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MballWidget, mball.mono), XtRString, "FALSE"},
-	{XtNwedges, XtCWedges, XtRInt, sizeof (int),
-	 XtOffset(MballWidget, mball.wedges), XtRString, "8"},	/*DEFAULTWEDGES */
-	{XtNrings, XtCRings, XtRInt, sizeof (int),
-	 XtOffset(MballWidget, mball.rings), XtRString, "4"},	/*DEFAULTRINGS */
-	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MballWidget, mball.orient), XtRString, "FALSE"},	/*DEFAULTORIENT */
-	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MballWidget, mball.practice), XtRString, "FALSE"},	/*DEFAULTPRACTICE */
-	{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
-	 XtOffset(MballWidget, mball.started), XtRString, "FALSE"},
-	{XtNselectCallback, XtCCallback, XtRCallback, sizeof (caddr_t),
-	 XtOffset(MballWidget, mball.select), XtRCallback, NULL}
+		{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
+		 XtOffset(MballWidget, core.width), XtRString, "200"},
+		{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
+		 XtOffset(MballWidget, core.height), XtRString, "400"},
+		{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
+		 XtOffset(MballWidget, mball.mono), XtRString, "FALSE"},
+		{XtNwedges, XtCWedges, XtRInt, sizeof (int),
+		 XtOffset(MballWidget, mball.wedges), XtRString, "8"},	/*DEFAULTWEDGES */
+		{XtNrings, XtCRings, XtRInt, sizeof (int),
+		 XtOffset(MballWidget, mball.rings), XtRString, "4"},	/*DEFAULTRINGS */
+		{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
+		 XtOffset(MballWidget, mball.orient), XtRString, "FALSE"},	/*DEFAULTORIENT */
+		{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
+		 XtOffset(MballWidget, mball.practice), XtRString, "FALSE"},	/*DEFAULTPRACTICE */
+		{XtNstart, XtCBoolean, XtRBoolean, sizeof (Boolean),
+		 XtOffset(MballWidget, mball.started), XtRString, "FALSE"},
+	      {XtNselectCallback, XtCCallback, XtRCallback, sizeof (caddr_t),
+	       XtOffset(MballWidget, mball.select), XtRCallback, NULL}
 };
 
-MballClassRec mballClassRec =
-{
+	MballClassRec mballClassRec =
 	{
-		(WidgetClass) & widgetClassRec,		/* superclass */
-		"Mball",	/* class name */
-		sizeof (MballRec),	/* widget size */
-		NULL,		/* class initialize */
-		NULL,		/* class part initialize */
-		FALSE,		/* class inited */
-		(XtInitProc) InitializeMball,	/* initialize */
-		NULL,		/* initialize hook */
-		XtInheritRealize,	/* realize */
-		actionsListMball,	/* actions */
-		XtNumber(actionsListMball),	/* num actions */
-		resourcesMball,	/* resources */
-		XtNumber(resourcesMball),	/* num resources */
-		NULLQUARK,	/* xrm class */
-		TRUE,		/* compress motion */
-		TRUE,		/* compress exposure */
-		TRUE,		/* compress enterleave */
-		TRUE,		/* visible interest */
-		(XtWidgetProc) DestroyMball,	/* destroy */
-		(XtWidgetProc) ResizeMball,	/* resize */
-		(XtExposeProc) ExposeMball,	/* expose */
-		(XtSetValuesFunc) SetValuesMball,	/* set values */
-		NULL,		/* set values hook */
-		XtInheritSetValuesAlmost,	/* set values almost */
-		NULL,		/* get values hook */
-		NULL,		/* accept focus */
-		XtVersion,	/* version */
-		NULL,		/* callback private */
-		defaultTranslationsMball,	/* tm table */
-		NULL,		/* query geometry */
-		NULL,		/* display accelerator */
-		NULL		/* extension */
-	},
-	{
-		0		/* ignore */
-	}
+		{
+			(WidgetClass) & widgetClassRec,		/* superclass */
+			"Mball",	/* class name */
+			sizeof (MballRec),	/* widget size */
+			NULL,	/* class initialize */
+			NULL,	/* class part initialize */
+			FALSE,	/* class inited */
+			(XtInitProc) InitializeMball,	/* initialize */
+			NULL,	/* initialize hook */
+			XtInheritRealize,	/* realize */
+			actionsListMball,	/* actions */
+			XtNumber(actionsListMball),	/* num actions */
+			resourcesMball,		/* resources */
+			XtNumber(resourcesMball),	/* num resources */
+			NULLQUARK,	/* xrm class */
+			TRUE,	/* compress motion */
+			TRUE,	/* compress exposure */
+			TRUE,	/* compress enterleave */
+			TRUE,	/* visible interest */
+			(XtWidgetProc) DestroyMball,	/* destroy */
+			(XtWidgetProc) ResizeMball,	/* resize */
+			(XtExposeProc) ExposeMball,	/* expose */
+			(XtSetValuesFunc) SetValuesMball,	/* set values */
+			NULL,	/* set values hook */
+			XtInheritSetValuesAlmost,	/* set values almost */
+			NULL,	/* get values hook */
+			NULL,	/* accept focus */
+			XtVersion,	/* version */
+			NULL,	/* callback private */
+			defaultTranslationsMball,	/* tm table */
+			NULL,	/* query geometry */
+			NULL,	/* display accelerator */
+			NULL	/* extension */
+		},
+		{
+			0	/* ignore */
+		}
 };
 
-static int  mapDirToWedge[(MAXWEDGES - MINWEDGES) / 2 + 1][COORD] =
+	static int  mapDirToWedge[(MAXWEDGES - MINWEDGES) / 2 + 1][COORD] =
 {
 	{
 		0, 4, 4, 4, 0, 4, 4, 4
@@ -580,10 +582,11 @@ GetMball(MballWidget w, XEvent * event, char **args, int nArgs)
 				cb.reason = (wedge - MINWEDGES) / 2 + MBALL_WEDGE2;
 				XtCallCallbacks((Widget) w, XtNselectCallback, &cb);
 			}
-		} else
+		} else {
 			(void) printf("%s corrupted: ", DATAFILE);
-		(void) printf("wedge %d should be even and between %d and %d\n",
-			      wedge, MINWEDGES, MAXWEDGES);
+			(void) printf("wedge %d should be even and between %d and %d\n",
+				      wedge, MINWEDGES, MAXWEDGES);
+		}
 		while ((c = getc(fp)) != EOF && c != SYMBOL);
 		(void) fscanf(fp, "%d", &ring);
 		if (ring >= MINRINGS) {
@@ -620,7 +623,7 @@ GetMball(MballWidget w, XEvent * event, char **args, int nArgs)
 		(void) fclose(fp);
 		(void) printf("%s: wedge %d, ring %d, orient %d, ",
 			      DATAFILE, wedge, ring, orient);
-		(void) printf("practice %d, moves %d", practice, moves);
+		(void) printf("practice %d, moves %d\n", practice, moves);
 	}
 }
 
@@ -634,7 +637,7 @@ WriteMball(MballWidget w, XEvent * event, char **args, int nArgs)
 	else {
 		(void) fprintf(fp, "wedge%c %d\n", SYMBOL, w->mball.wedges);
 		(void) fprintf(fp, "ring%c %d\n", SYMBOL, w->mball.rings);
-		(void) fprintf(fp, "orient%c: %d\n", SYMBOL, (w->mball.orient) ? 1 : 0);
+		(void) fprintf(fp, "orient%c %d\n", SYMBOL, (w->mball.orient) ? 1 : 0);
 		(void) fprintf(fp, "practice%c %d\n", SYMBOL, (w->mball.practice) ? 1 : 0);
 		(void) fprintf(fp, "moves%c %d\n", SYMBOL, NumMoves());
 		PrintStartPosition(fp, w);
@@ -651,9 +654,7 @@ UndoMball(MballWidget w, XEvent * event, char **args, int nArgs)
 		int         wedge, ring, direction, control;
 
 		GetMove(&wedge, &ring, &direction, &control);
-		direction = (direction < COORD) ? ((direction < CUTS) ?
-					      (direction + CUTS / 2) % CUTS :
-		(direction + CUTS / 2) % CUTS + CUTS) : 3 * COORD - direction;
+		direction = (direction < COORD) ? direction : 3 * COORD - direction;
 		if (control)
 			MoveControlCb(w, wedge, direction);
 		else {
