@@ -6,7 +6,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 96	David Albert Bagley, bagleyd@hertz.njit.edu
+#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
 #
 #                   All Rights Reserved
 #
@@ -36,6 +36,7 @@
  ***********************************************************************/
 
 #define XtNselectCallback "selectCallback"
+#define XtNuserName "userName"
 #define XtNmono "mono"
 #define XtNwedges "wedges"
 #define XtNrings "rings"
@@ -51,6 +52,7 @@
 #define XtNwedgeColor5 "wedgeColor5"
 #define XtNwedgeColor6 "wedgeColor6"
 #define XtNwedgeColor7 "wedgeColor7"
+#define XtCUserName "UserName"
 #define XtCMono "Mono"
 #define XtCWedges "Wedges"
 #define XtCRings "Rings"
