@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 96	David Albert Bagley, bagleyd@hertz.njit.edu
+#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
 #
 #                   All Rights Reserved
 #
@@ -31,12 +31,41 @@
 #include "Mball.h"
 
 /*** random number generator ***/
-/* insert your favorite */
+#if HAVE_RAND48
+#define SRAND srand48
+#define LRAND lrand48
+#define MAXRAND (2147483648.0)
+#else /* HAVE_RAND48 */
+#if HAVE_RANDOM
+#define SRAND srand48
+#define LRAND lrand48
+#define MAXRAND (2147483648.0)
+#else /* HAVE_RANDOM */
+#if HAVE_RAND
+#define SRAND srand48
+#define LRAND lrand48
+#ifdef AIXV3
+#define MAXRAND (2147483648.0)
+#else
+#define MAXRAND (32768.0)
+#endif
+#endif /* HAVE_RAND */
+#endif /* HAVE_RANDOM */
+#endif /* HAVE_RAND48 */
+
+#ifndef SRAND
 extern void SetRNG(long int s);
-extern long LongRNG(void);
 
 #define SRAND(X) SetRNG((long) X)
+#endif
+#ifndef LRAND
+extern long LongRNG(void);
+
 #define LRAND() LongRNG()
+#endif
+#ifndef MAXRAND
+#define MAXRAND (2147483648.0)
+#endif
 
 #define NRAND(X) ((int)(LRAND()%(X)))
 
@@ -107,6 +136,7 @@ typedef struct _MballPart {
 	GC          wedgeGC[MAXWEDGES];
 	GC          inverseGC;
 	String      wedgeName[MAXWEDGES];
+	char       *username;
 	XtCallbackList select;
 } MballPart;
 
@@ -130,7 +160,7 @@ extern MballLoc *startLoc[MAXWEDGES];
 
 extern void MoveMball(MballWidget w, int wedge, int ring, int direction, int control);
 
-							       /* extern void SolveWedges(); *//* For future auto-solver */
+											       /* extern void SolveWedges(); *//* For future auto-solver */
 extern void DrawAllWedges(MballWidget w);
 extern Boolean CheckSolved(MballWidget w);
 extern void InitMoves(void);
