@@ -6,7 +6,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 96	David Albert Bagley, bagleyd@hertz.njit.edu
+#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
 #
 #                   All Rights Reserved
 #
@@ -31,14 +31,20 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <errno.h>
 #ifdef VMS
 #include <unixlib.h>
-#define getlogin cuserid
+#define getlogin() cuserid(NULL)
 #else
-#ifndef apollo
+#if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #endif
+#if HAVE_FCNTL_H
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#endif
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
 #include <X11/Shell.h>
@@ -66,12 +72,22 @@
 
 #define MAXRINGS 6
 #define MAXRECORD 32767
+#define FILENAMELEN 1024
+#define USERNAMELEN 128
+#define NOACCESS "noaccess"
+#define NOBODY "nobody"
+
+typedef struct {
+	int         score;
+	char        name[USERNAMELEN];
+} GameRecord;
 
 static void Initialize(Widget w);
 static void CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData);
 
 static void PrintRecord(int wedges, int rings, Boolean orient, Boolean practice);
 static int  HandleSolved(int counter, int wedges, int rings, Boolean orient);
+static void InitRecords(void);
 static void ReadRecords(void);
 static void WriteRecords(void);
 
@@ -84,10 +100,11 @@ static void motif_print(Widget w, char *text);
 static Arg  arg[5];
 static Widget moves, record, message, mball, orientSwitch, practiceSwitch,
             wedge[(MAXWEDGES - MINWEDGES) / 2 + 1], ring;
-static int  mballRecord[2][(MAXWEDGES - MINWEDGES) / 2 + 1]
+static GameRecord mballRecord[2][(MAXWEDGES - MINWEDGES) / 2 + 1]
 [MAXRINGS - MINRINGS + 1];
 static int  movesDsp = 0;
 static char messageDsp[128] = "Welcome";
+static char usernameDsp[USERNAMELEN] = "";
 static char buff[256];
 
 static char *wedgeString[] =
@@ -102,29 +119,27 @@ usage(void)
 	(void) fprintf(stderr,
 	     "\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
 	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]][-fg {color}] [-bg {color}]\n");
+		       "\t[-display [{host}]:[{vs}]] [-mono]\n");
 	(void) fprintf(stderr,
-		       "\t[-{border|bd} {color}] [-mono] [-{wedges {int}}] [-{rings {int}}]\n");
+		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
 	(void) fprintf(stderr,
-		       "\t[-[no]orient] [-[no]practice] [-wedge{0|1|2|3|4|5|6|7} {color}]\n");
+	     "\t[-{border|bd} {color}] [-wedge{0|1|2|3|4|5|6|7} {color}]\n");
+	(void) fprintf(stderr,
+		       "\t[-{wedges {int}}] [-{rings {int}}] [-[no]orient] [-[no]practice]\n");
+	(void) fprintf(stderr,
+		       "\t[-username {string}]\n");
 	exit(1);
 }
 
 static XrmOptionDescRec options[] =
 {
-	{"-fg", "*mball.Foreground", XrmoptionSepArg, NULL},
-	{"-bg", "*Background", XrmoptionSepArg, NULL},
-	{"-foreground", "*mball.Foreground", XrmoptionSepArg, NULL},
-	{"-background", "*Background", XrmoptionSepArg, NULL},
-	{"-border", "*mball.pieceBorder", XrmoptionSepArg, NULL},
-	{"-bd", "*mball.pieceBorder", XrmoptionSepArg, NULL},
 	{"-mono", "*mball.mono", XrmoptionNoArg, "TRUE"},
-	{"-wedges", "*mball.wedges", XrmoptionSepArg, NULL},
-	{"-rings", "*mball.rings", XrmoptionSepArg, NULL},
-	{"-orient", "*mball.orient", XrmoptionNoArg, "TRUE"},
-	{"-noorient", "*mball.orient", XrmoptionNoArg, "FALSE"},
-	{"-practice", "*mball.practice", XrmoptionNoArg, "TRUE"},
-	{"-nopractice", "*mball.practice", XrmoptionNoArg, "FALSE"},
+	{"-fg", "*mball.Foreground", XrmoptionSepArg, NULL},
+	{"-foreground", "*mball.Foreground", XrmoptionSepArg, NULL},
+	{"-bg", "*Background", XrmoptionSepArg, NULL},
+	{"-background", "*Background", XrmoptionSepArg, NULL},
+	{"-bd", "*mball.pieceBorder", XrmoptionSepArg, NULL},
+	{"-border", "*mball.pieceBorder", XrmoptionSepArg, NULL},
 	{"-wedge0", "*mball.wedgeColor0", XrmoptionSepArg, NULL},
 	{"-wedge1", "*mball.wedgeColor1", XrmoptionSepArg, NULL},
 	{"-wedge2", "*mball.wedgeColor2", XrmoptionSepArg, NULL},
@@ -133,6 +148,13 @@ static XrmOptionDescRec options[] =
 	{"-wedge5", "*mball.wedgeColor5", XrmoptionSepArg, NULL},
 	{"-wedge6", "*mball.wedgeColor6", XrmoptionSepArg, NULL},
 	{"-wedge7", "*mball.wedgeColor7", XrmoptionSepArg, NULL},
+	{"-wedges", "*mball.wedges", XrmoptionSepArg, NULL},
+	{"-rings", "*mball.rings", XrmoptionSepArg, NULL},
+	{"-orient", "*mball.orient", XrmoptionNoArg, "TRUE"},
+	{"-noorient", "*mball.orient", XrmoptionNoArg, "FALSE"},
+	{"-practice", "*mball.practice", XrmoptionNoArg, "TRUE"},
+	{"-nopractice", "*mball.practice", XrmoptionNoArg, "FALSE"},
+	{"-username", "*mball.userName", XrmoptionSepArg, NULL}
 };
 
 int
@@ -140,7 +162,7 @@ main(int argc, char **argv)
 {
 	Widget      toplevel;
 	Widget      panel, panel2;
-  Widget      rowcol, rowcol2, rowcol3, rowcol4, rowcol5, rowcol6;
+	Widget      rowcol, rowcol2, rowcol3, rowcol4, rowcol5, rowcol6;
 	Pixmap      mouseLeftCursor, mouseRightCursor;
 	Pixel       fg, bg;
 	int         i;
@@ -272,11 +294,13 @@ Initialize(Widget w)
 {
 	int         wedges, rings;
 	Boolean     orient, practice;
+	String      username;
 
 	XtVaSetValues(w,
 		      XtNstart, FALSE,
 		      NULL);
 	XtVaGetValues(w,
+		      XtNuserName, &username,
 		      XtNwedges, &wedges,
 		      XtNrings, &rings,
 		      XtNorient, &orient,
@@ -287,7 +311,16 @@ Initialize(Widget w)
 		XmScaleSetValue(ring, rings);
 	XmToggleButtonSetState(orientSwitch, orient, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
+	InitRecords();
 	ReadRecords();
+	(void) strcpy(usernameDsp, username);
+	if (!strcmp(usernameDsp, "") || !strcmp(usernameDsp, NOACCESS) ||
+	    !strcmp(usernameDsp, NOBODY)) {
+		/* The NOACCESS is not necasary, but it stops people from being cute. */
+		(void) sprintf(usernameDsp, "%s", getlogin());
+		if (!strcmp(usernameDsp, "") || !strcmp(usernameDsp, NOACCESS))
+			(void) sprintf(usernameDsp, "%s", NOBODY);	/* It really IS nobody */
+	}
 	PrintRecord(wedges, rings, orient, practice);
 }
 
@@ -335,7 +368,7 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 				movesDsp = 0;
 			else {
 				if (HandleSolved(movesDsp, wedges, rings, orient))
-					(void) sprintf(messageDsp, "Congratulations %s!!", getlogin());
+					(void) sprintf(messageDsp, "Congratulations %s!!", usernameDsp);
 				else
 					(void) strcpy(messageDsp, "Solved!");
 			}
@@ -511,10 +544,12 @@ PrintRecord(int wedges, int rings, Boolean orient, Boolean practice)
 		motif_print(record, "practice");
 	else if (rings > MAXRINGS)
 		motif_print(record, "NOT RECORDED");
-	else if (mballRecord[i][w][r] >= MAXRECORD)
-		motif_print(record, "NEVER");
-	else {
-		(void) sprintf(buff, "%d", mballRecord[i][w][r]);
+	else if (mballRecord[i][w][r].score >= MAXRECORD) {
+		(void) sprintf(buff, "NEVER %s", NOACCESS);
+		motif_print(record, buff);
+	} else {
+		(void) sprintf(buff, "%d %s",
+		      mballRecord[i][w][r].score, mballRecord[i][w][r].name);
 		motif_print(record, buff);
 	}
 }
@@ -526,10 +561,13 @@ HandleSolved(int counter, int wedges, int rings, Boolean orient)
 	int         w = (wedges - MINWEDGES) / 2;
 	int         r = rings - MINRINGS;
 
-	if (rings <= MAXRINGS && counter < mballRecord[i][w][r]) {
-		mballRecord[i][w][r] = counter;
-		if (orient && (mballRecord[i][w][r] < mballRecord[!i][w][r]))
-			mballRecord[!i][w][r] = counter;
+	if (rings <= MAXRINGS && counter < mballRecord[i][w][r].score) {
+		mballRecord[i][w][r].score = counter;
+		(void) strcpy(mballRecord[i][w][r].name, usernameDsp);
+		if (orient && counter < mballRecord[!i][w][r].score) {
+			mballRecord[!i][w][r].score = counter;
+			(void) strcpy(mballRecord[!i][w][r].name, usernameDsp);
+		}
 		WriteRecords();
 		PrintRecord(wedges, rings, orient, False);
 		return TRUE;
@@ -537,16 +575,27 @@ HandleSolved(int counter, int wedges, int rings, Boolean orient)
 	return FALSE;
 }
 
+static void
+InitRecords(void)
+{
+	int         i, j, orient;
+
+	for (orient = 0; orient < 2; orient++)
+		for (i = 0; i < (MAXWEDGES - MINWEDGES) / 2 + 1; i++)
+			for (j = 0; j < MAXRINGS - MINRINGS + 1; j++) {
+				mballRecord[orient][i][j].score = MAXRECORD;
+				(void) strcpy(mballRecord[orient][i][j].name, NOACCESS);
+			}
+}
+
+
 static void
 ReadRecords(void)
 {
 	FILE       *fp;
 	int         i, j, n, orient;
+	char        username[USERNAMELEN];
 
-	for (orient = 0; orient < 2; orient++)
-		for (i = 0; i < (MAXWEDGES - MINWEDGES) / 2 + 1; i++)
-			for (j = 0; j < MAXRINGS - MINRINGS + 1; j++)
-				mballRecord[orient][i][j] = MAXRECORD;
 	if ((fp = fopen(SCOREFILE, "r")) == NULL) {
 		(void) sprintf(buff, "Can not open %s, taking defaults.", SCOREFILE);
 		motif_print(message, buff);
@@ -554,8 +603,11 @@ ReadRecords(void)
 		for (orient = 0; orient < 2; orient++)
 			for (i = 0; i < (MAXWEDGES - MINWEDGES) / 2 + 1; i++)
 				for (j = 0; j < MAXRINGS - MINRINGS + 1; j++) {
-					(void) fscanf(fp, "%d", &n);
-					mballRecord[orient][i][j] = n;
+					(void) fscanf(fp, "%d %s\n", &n, username);
+					if (n <= mballRecord[orient][i][j].score) {
+						mballRecord[orient][i][j].score = n;
+						(void) strcpy(mballRecord[orient][i][j].name, username);
+					}
 				}
 		(void) fclose(fp);
 	}
@@ -567,18 +619,43 @@ WriteRecords(void)
 	FILE       *fp;
 	int         i, j, orient;
 
+	ReadRecords();		/* Maybe its been updated by another */
 	if ((fp = fopen(SCOREFILE, "w")) == NULL) {
 		(void) sprintf(buff, "Can not write to %s.", SCOREFILE);
 		motif_print(message, buff);
 	} else {
+#if HAVE_FCNTL_H
+		int         lfd;
+		char        lockfile[FILENAMELEN];
+
+		(void) strcpy(lockfile, SCOREFILE);
+		(void) strcat(lockfile, ".lock");
+		while (((lfd = open(lockfile, O_CREAT | O_EXCL, 0644)) < 0) &&
+		       errno == EEXIST)
+			(void) sleep(1);
+		if (lfd < 0) {
+#if 1
+			(void) fprintf(stderr, "Lock file exists... guessing its an old one.\n");
+#else
+			(void) fprintf(stderr, "Lock file exists... score not recorded - sorry.\n"
+				);
+			return;
+#endif
+		}
+#endif
 		for (orient = 0; orient < 2; orient++) {
 			for (i = 0; i < (MAXWEDGES - MINWEDGES) / 2 + 1; i++) {
 				for (j = 0; j < MAXRINGS - MINRINGS + 1; j++)
-					(void) fprintf(fp, "%d ", mballRecord[orient][i][j]);
+					(void) fprintf(fp, "%d %s\n",
+						       mballRecord[orient][i][j].score, mballRecord[orient][i][j].name);
 				(void) fprintf(fp, "\n");
 			}
 			(void) fprintf(fp, "\n");
 		}
+#if HAVE_FCNTL_H
+		(void) close(lfd);
+		(void) unlink(lockfile);
+#endif
 		(void) fclose(fp);
 	}
 }
