@@ -6,7 +6,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 96	David Albert Bagley, bagleyd@hertz.njit.edu
+#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
 #
 #                   All Rights Reserved
 #
@@ -36,6 +36,7 @@
  ***********************************************************************/
 
 #define XtNselectCallback "selectCallback"
+#define XtNuserName "userName"
 #define XtNtiles "tiles"
 #define XtNfaces "faces"
 #define XtNorient "orient"
@@ -53,6 +54,7 @@
 #define XtNfaceColor5 "faceColor5"
 #define XtNfaceColor6 "faceColor6"
 #define XtNfaceColor7 "faceColor7"
+#define XtCUserName "UserName"
 #define XtCTiles "Tiles"
 #define XtCFaces "Faces"
 #define XtCOrient "Orient"
