@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 96	David Albert Bagley, bagleyd@hertz.njit.edu
+#  Copyright (c) 1994 - 97	David Albert Bagley, bagleyd@bigfoot.com
 #
 #                   All Rights Reserved
 #
@@ -110,6 +110,8 @@ static XtActionsRec actionsListRubik2D[] =
 
 static XtResource resourcesRubik2D[] =
 {
+	{XtNuserName, XtCUserName, XtRString, sizeof (String),
+	 XtOffset(RubikWidget, rubik.username), XtRString, "nobody"},
 	{XtNfaceColor0, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(RubikWidget, rubik.faceName[0]), XtRString, "Red"},
 	{XtNfaceColor1, XtCLabel, XtRString, sizeof (String),
